@@ -1770,14 +1770,3 @@ int32_t SPVM__Sys__IO__Constant___IOFBF(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 }
 
-int32_t SPVM__Sys__IO__Constant__FIONBIO(SPVM_ENV* env, SPVM_VALUE* stack) {
-
-#ifdef FIONBIO
-  stack[0].ival = FIONBIO;
-  return 0;
-#else
-  env->die(env, stack, "FIONBIO is not defined in this system", __func__, FILE_NAME, __LINE__);
-  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
-#endif
-  
-}
