@@ -10,6 +10,11 @@
 #include <errno.h>
 #include <assert.h>
 
+#if defined(_WIN32)
+#else
+  #include <sys/un.h>
+#endif
+
 static const char* FILE_NAME = "Sys/Socket.c";
 
 int32_t SPVM__Sys__Socket__socket_errno(SPVM_ENV* env, SPVM_VALUE* stack) {
@@ -907,3 +912,56 @@ int32_t SPVM__Sys__Socket__sendto(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
+int32_t SPVM__Sys__Socket__to_family_sockaddr(SPVM_ENV* env, SPVM_VALUE* stack) {
+  int32_t error_id = 0;
+  
+  void* obj_addr = stack[0].oval;
+  
+  if (!obj_addr) {
+    return env->die(env, stack, "The $addr must be defined", __func__, FILE_NAME, __LINE__);
+  }
+  
+  const struct sockaddr* addr = env->get_pointer(env, stack, obj_addr);
+  
+  int32_t sa_family = addr->sa_family;
+  
+  void* obj_addr_child = NULL;
+  
+  switch (sa_family) {
+    case AF_INET: {
+      struct sockaddr_in* addr_in = env->new_memory_stack(env, stack, sizeof(struct sockaddr_in));
+      memcpy(addr_in, addr, sizeof(struct sockaddr_in));
+      obj_addr_child = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Sockaddr::In", addr_in, &error_id, __func__, FILE_NAME, __LINE__);
+      if (error_id) { return error_id; }
+      
+      break;
+    }
+    case AF_INET6: {
+      struct sockaddr_in6* addr_in6 = env->new_memory_stack(env, stack, sizeof(struct sockaddr_in6));
+      memcpy(addr_in6, addr, sizeof(struct sockaddr_in6));
+      obj_addr_child = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Sockaddr::In6", addr_in6, &error_id, __func__, FILE_NAME, __LINE__);
+      if (error_id) { return error_id; }
+      
+      break;
+    }
+    case AF_UNIX: {
+#if defined(_WIN32)
+      env->die(env, stack, "AF_UNIX is not supported in this system(defined(_WIN32))", sa_family, __func__, FILE_NAME, __LINE__);
+      return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
+#else
+      struct sockaddr_un* addr_un = env->new_memory_stack(env, stack, sizeof(struct sockaddr_un));
+      memcpy(addr_un, addr, sizeof(struct sockaddr_un));
+      obj_addr_child = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Sockaddr::Un", addr_un, &error_id, __func__, FILE_NAME, __LINE__);
+      if (error_id) { return error_id; }
+#endif
+      break;
+    }
+    default: {
+      return env->die(env, stack, "The address family %d is not available.", sa_family, __func__, FILE_NAME, __LINE__);
+    }
+  }
+  
+  stack[0].oval = obj_addr_child;
+  
+  return 0;
+}
