@@ -259,12 +259,6 @@ The length of the option value must be less than or equal to the option length.
 
 If the system call failed, an exception will be thrown with the error code set to the class id of the L<Error::System> class.
 
-=head2 setsockopt_int
-
-  static method setsockopt_int : int ($sockfd : int, $level : int, $optname : int, $optval : int);
-
-The same as L</"setsockopt">, but the option value can be specifed by the C<int> type.
-
 =head2 getsockopt
 
   static method getsockopt : int ($sockfd : int, $level : int, $optname : int, $optval : mutable string, $optlen_ref : int*);
@@ -281,11 +275,11 @@ The length of the option value must be less than or equal to the option length.
 
 If the system call failed, an exception will be thrown with the error code set to the class id of the L<Error::System> class.
 
-=head2 getsockopt_int
+The $optval is a string. The following is an example to get an int value.
 
-  static method getsockopt_int : int ($sockfd : int, $level : int, $optname : int, $optval_ref : int*);
-
-The same as L</"getsockopt">, but the option value can be specifed by the C<int> type.
+  my $optval_int_ref = [0];
+  Fn->memcpy($result_ref, 0, $optval, 0, 4);
+  my $optval_int = $optval_int_ref->[0];
 
 =head2 getaddrinfo_raw
 
@@ -377,6 +371,26 @@ Portalbe C<strerror> related to the errors of the socket.
 
 See the L<ioctlsocket|https://learn.microsoft.com/en-us/windows/win32/api/winsock/nf-winsock-ioctlsocket> function in Windows.
 
+static method to_child_sockaddr : int ($addr : Sys::Socket::Sockaddr);
+
+=head2 to_family_sockaddr
+
+  static method to_family_sockaddr : Sys::Socket::Sockaddr ($addr : Sys::Socket::Sockaddr);
+
+Copies the $addr and creates a new L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> object corresponding to the address family, and returns it.
+
+If address family is AF_INET, returns a L<Sys::Socket::Sockaddr::In|SPVM::Sys::Socket::Sockaddr::In> object.
+
+If address family is AF_INET6, returns a L<Sys::Socket::Sockaddr::In6|SPVM::Sys::Socket::Sockaddr::In6> object.
+
+If address family is AF_UNIX, returns a L<Sys::Socket::Sockaddr::Un|SPVM::Sys::Socket::Sockaddr::Un> object.
+
+Exceptions:
+
+The $addr must be defined. Otherwise an exception is thrown.
+
+If the address family is not available, an exception is thrown.
+
 =head1 Copyright & License
 
 Copyright (c) 2023 Yuki Kimoto
