@@ -149,9 +149,9 @@ int32_t SPVM__Sys__Socket__Addrinfo__set_ai_addrlen(SPVM_ENV* env, SPVM_VALUE* s
   return 0;
 }
 
-int32_t SPVM__Sys__Socket__Addrinfo__copy_ai_addr(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPVM__Sys__Socket__Addrinfo__ai_addr(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error = 0;
   
   void* obj_self = stack[0].oval;
   
@@ -184,13 +184,13 @@ int32_t SPVM__Sys__Socket__Addrinfo__copy_ai_addr(SPVM_ENV* env, SPVM_VALUE* sta
     
     // Calls the clone method.
     {
-      void* obj_ai_addr = env->new_pointer_object_by_name(env, stack, sockaddr_class_name, tmp_ai_addr, &e, __func__, FILE_NAME, __LINE__);
-      if (e) { return e; }
+      void* obj_ai_addr = env->new_pointer_object_by_name(env, stack, sockaddr_class_name, tmp_ai_addr, &error, __func__, FILE_NAME, __LINE__);
+      if (error) { return error; }
       
       stack[0].oval = obj_ai_addr;
       int32_t args_stack_length = 1;
-      e = env->call_instance_method_by_name(env, stack, "clone", args_stack_length, __func__, FILE_NAME, __LINE__);
-      if (e) { return e; };
+      env->call_instance_method_by_name(env, stack, "clone", args_stack_length, &error, __func__, FILE_NAME, __LINE__);
+      if (error) { return error; };
       obj_ai_addr_clone = stack[0].oval;
     }
   }
@@ -200,7 +200,7 @@ int32_t SPVM__Sys__Socket__Addrinfo__copy_ai_addr(SPVM_ENV* env, SPVM_VALUE* sta
   return 0;
 }
 
-int32_t SPVM__Sys__Socket__Addrinfo__copy_ai_canonname(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPVM__Sys__Socket__Addrinfo__ai_canonname(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_self = stack[0].oval;
   
