@@ -56,7 +56,7 @@ Sets C<sin_family>.
 
 =head2 copy_sin_addr
 
-  method copy_sin_addr : Sys::Socket::In_addr ();
+  method sin_addr : Sys::Socket::In_addr ();
 
 Copies C<sin_addr>. This is a L<Sys::Socket::In_addr|SPVM::Sys::Socket::In_addr> object.
 
@@ -78,9 +78,9 @@ Gets C<sin_port>.
 
 Sets C<sin_port>.
 
-=head2 sizeof
+=head2 size
 
-  method sizeof : int ()
+  method size : int ()
 
 The size of C<struct sockaddr_in>.
 
