@@ -80,7 +80,7 @@ Sets C<sin6_scope_id>.
 
 =head2 copy_sin6_addr
 
-  method copy_sin6_addr : Sys::Socket::In6_addr ();
+  method sin6_addr : Sys::Socket::In6_addr ();
 
 Copies C<sin6_addr>. This is a L<Sys::Socket::In6_addr|SPVM::Sys::Socket::In6_addr> object.
 
@@ -102,9 +102,9 @@ Gets C<sin6_port>.
 
 Sets C<sin6_port>.
 
-=head2 sizeof
+=head2 size
 
-  method sizeof : int ()
+  method size : int ()
 
 The size of C<struct sockaddr_in6>.
 
