@@ -54,7 +54,7 @@ Sets C<sun_family>.
 
 =head2 copy_sun_path
 
-  method copy_sun_path : string ();
+  method sun_path : string ();
 
 Copies C<sun_path>.
 
@@ -64,9 +64,9 @@ Copies C<sun_path>.
 
 Sets C<sun_path>.
 
-=head2 sizeof
+=head2 size
 
-  method sizeof : int ()
+  method size : int ()
 
 The size of C<struct sockaddr_un>.
 
